@@ -28,6 +28,7 @@ class SKLearnScaffoldDefinition(WrittenModelScaffoldDefinition):
 
     model_framework = SKLEARN
     model_filename = 'model.joblib'
+    _build_args = {}
 
     @property
     def model_framework_requirements(self):
@@ -37,9 +38,11 @@ class SKLearnScaffoldDefinition(WrittenModelScaffoldDefinition):
 
     @property
     def build_args(self) -> Dict:
-        return {}
+        return self._build_args
 
     def serialize_model_to_directory(self, model_directory):
         serialized_model = _serialize_sklearn_model(self.model)
+        if self.python_major_minor:
+            self._build_args['PYVERSION'] = self.python_major_minor
         with open(pathlib.Path(model_directory, self.model_filename), 'wb') as f:
             f.write(serialized_model.read())
