@@ -26,7 +26,7 @@ args, _ = parser.parse_known_args()
 
 if __name__ == '__main__':
 
-    model = TransformerModel(args.model_name, args.task, args.has_hybrid_args, args.has_named_args)
+    model = TransformerModel(args.model_name, args.task, args.has_named_args, args.has_hybrid_args)
     model.load()
     B10Server(workers=1).start([model])
 
