@@ -18,7 +18,21 @@ class KerasModel(kfserving.KFModel):
         self._model = keras.models.load_model(self.model_dir)
         self.ready = True
 
-    def predict(self, request: Dict) -> Dict[str, List]:
+    def preprocess(self, request: Dict) -> Dict:
+        """
+        Incorporate any pre-processing information required by the model here.
+
+        These might be feature transformations that are tightly coupled to the model.
+        """
+        return request
+
+    def postprocess(self, request: Dict) -> Dict:
+        """
+        Incorporate any post-processing required by the model here.
+        """
+        return request
+
+    def predict(self, request: Dict) -> Dict:
         response = {}
         try:
             instances = request['instances']
